import logging

from .models import SecurityScheme, Tag
from .response import Response
from .spec import SpecTree

__all__ = ["SpecTree", "Response", "Tag", "SecurityScheme"]

# setup library logging
logging.getLogger(__name__).addHandler(logging.NullHandler())



from .base import BasePlugin
from .falcon_plugin import FalconAsgiPlugin, FalconPlugin
from .flask_plugin import FlaskPlugin
from .starlette_plugin import StarlettePlugin

PLUGINS = {
    "base": BasePlugin,
    "flask": FlaskPlugin,
    "falcon": FalconPlugin,
    "falcon-asgi": FalconAsgiPlugin,
    "starlette": StarlettePlugin,
}
